######################################################################################################################
#                                                                                                                    #
#                                               Archive utilities                                                    #
#                                                                                                                    #
######################################################################################################################

# Tarball name (only used for project from local directory)
: ${tarName:=$(basename $srcFile)-$PACKAGE_VERSION}

# Default archive strip level
: ${STRIP_LEVEL:=1}

###########################################################################
#
# Load the ARCHIVE-specific script then extract the sources into folder
#
# This script must define one function, called with the following parameters
#
#	ARCHIVE_extract
#		srcFile		The archive absolute path
#		destDir		The destination folder absolute path
#
###########################################################################
extract() {
	local srcFile="$1"
	local destDir="$2"

	case $(basename $srcFile) in
		*.tar* | *.txz  | *.tbz | *.tbz2| *.tgz)
			archive_tool="tar"
			;;
		*.zip)
			archive_tool="zip"
			;;
		*.*)
			# TODO
			fatal 1 "URL scheme for '$srcFile' not implemented yet"
			;;
		*)
			# Note the tarball is named after the package name and version, separated by a dash, not an underscore
			for tarsfx in tar tar.gz tar.bz2 tar.xz txz tbz tbz2 tgz zip; do
				srcFile="${downloadDir}/${tarName}.${tarsfx}"
				if [ -r "$srcFile" ]; then 
					if [ "$tarsfx" = "zip" ]; then 
						archive_tool="zip"
					else
						archive_tool="tar"
					fi
					break; 
				fi
			done
			;;
	esac
	
	if [ -n "$archive_tool" ]; then
		# Load the script
		archive_script=$(search_script archive/${archive_tool}_utils.sh)
		if [ -z "$archive_script" ]; then
			fatal 1 "Don't find handler to extract from the $archive_script Archive Utility"
		fi
		load_script_once "$archive_script"
		
		# Launch extract command
		${archive_tool}_extract ${srcFile} ${destDir}
	else
		fatal 2 "Unrecognized archive tool for '$(basename $srcFile)'"
	fi
}