#
# Import utilities
#
# When importing source code, two variables are checked:
#       DO_NOT_EXTRACT_SOURCE   If set to true, a tarball is not extracted
#       LINK_SOURCE_ONLY        Keep source in the download directory, just link it in project
#                               This variable set to true implied DO_NOT_EXTRACT_SOURCE
#

require_script_once "fetch_utils.sh"
require_script_once "archive_utils.sh"

note "STRIP_LEVEL='$STRIP_LEVEL'"

# Package to create
: ${projName:=$PACKAGE_ID}
destDir="${workDir}"
note "destDir='$destDir'"

if [ -n "$taskBuildStatusDir" ]; then
	outDir="${taskBuildStatusDir%/_build}"
else
	outDir="${destDir}"
fi
note "outDir='$outDir'"

########################################################################################################################
# Gross HACK to import CDT projects, check if the source url is in workspace and if it is CDT Project, if so, do not
# extract generated tarball from "Fetch" task (first part of hack)
# Note this may be a temporary solution only...
isLocalProject=false
if [ "$srcUrl" == "$WORKSPACE_LOC/$PACKAGE_NAME" ]; then
	if [ -r "$srcUrl/.project" ]; then
		local realProjName=$(sed -n -e 's|^.*<name>\([^<]*\)</name>.*$|\1|p' < "$srcUrl/.project" | head -1)
		if [ "$realProjName" == "$PACKAGE_NAME" ]; then
			isLocalProject=true
		fi
	fi
fi
note "isLocalProject='$isLocalProject'"

# end of HACK
########################################################################################################################

#
# Cleans a package working directory before importing
#
cleanup_package_working_directory() {
	local destDir="$1"
	local what whatname taskfile task

	# Create project directory and ensure it is empty
	log "Cleanup project directory '$destDir'"
	mkdir -p ${destDir}
	for what in ${destDir}/* ${destDir}/.[^.]* ${destDir}/..?*; do
		whatname=$(basename "$what")
		if [ ! -d "$what" ]; then 
			if [ "$whatname" != ".project" -a "$whatname" != ".cproject" ]; then
				rm -f "$what" 
			fi
			continue
		fi
		if [ "$whatname" = "_build" ]; then
			# We restart from fresh sources; forget already applied patches...
			mkdir -p "$what/.ac6_build"
			rm -rf "$what"/* 
			rm -rf "$what/.ac6_build/applied_patches" "$what/.ac6_build/backups"
			tasks=$(ls -u "$what/.ac6_build" \
			       | sed -n -e 's|^task\.\([^.]*\)\.'"$recipe_id"'.*$|\1|p' \
			       | sort | uniq | grep -v import)
			for task in $tasks; do
				rm -f "$what"/.ac6_build/task.$task.$recipe_id
				rm -f "$what"/.ac6_build/task.$task.$recipe_id.outstamp
				rm -f "$what"/.ac6_build/task.$task.$recipe_id.poison
				rm -f "$what"/.ac6_build/task.$task.$recipe_id.includes
			done
		else
			rm -rf "$what"
		fi
	done
}

##################################################################
#				
# Unpack/Import the source into future project location 
#
###################################################################
base_do_import() {
	note "srcFile='$srcFile'"
	
	# If source is SCMS, use the scms function to import the sources into workspace
	if [ -n "$scms_tool" ]; then
		${scms_tool}_import "$srcUrl" "$srcFile" "$srcDir"
		local status=$?
		return $status
	fi
	
	# If source is file://, search it, either as resource or on the local machine
	local srcPath=${srcUrl#file://}
	if [ "$srcPath" != "$srcUrl" ]; then
		local searchDir
		srcPath=${srcUrl#file://}
		case $srcPath in
			/*)
				log "Searching $srcPath on local machine"
				searchDir="$(dirname $srcPath)"
				;;
			*)
				log "Searching $srcPath in recipe resources"
				searchDir="$recipe_metadatadir/resources/$(dirname $srcPath)"
				;;
		esac
		srcPath=$(basename $srcPath)
		srcFile=$(machine_specific_file $searchDir $srcPath)
		if [ ! -r "$srcFile" ]; then
			fatal 1 "Resource file '$srcPath' not found"
		fi
	fi
		
	if [ "$srcUrl" = "empty" ]; then
		true # Nothing to do
	elif [ "$LINK_SOURCE_ONLY" = "true" ]; then
		log_exec mkdir -p "${destDir}"
		log_exec ln -nfs "${srcFile}" "${destDir}"
	elif $isLocalProject; then ### Second part of CDT hack
		log "Project '$srcFilename' already exists in workspace $WORKSPACE_LOC, the source will not be extracted again"
	elif ! $srcUnpack; then
		log_exec mkdir -p "${destDir}"
		log_exec cp "${srcFile}" "${destDir}"
	else
		# If source is archive or local folder, extract the sources
		extract "${srcFile}" "${destDir}"
	fi
}
