######################################################################################################################
#                                                                                                                    #
#                                             Ext[2;3;4] Rootfs utilities                                            #
#                                                                                                                    #
######################################################################################################################


##################################################
# Generate the EXT2/3/4 image using mkfs.ext2/3/4
# -i bytes-per-inode
# -d root-directory
# -F force create filesystem
# fsck.ext2/3/4
##################################################
extfs_generate() {
	local imgRoot="$1"
	local imgType="${2:-ext2}"
	local imgName="$3"
	local partName="$4"
	local defaultSize=$(du -s $imgRoot | cut -f1)
	defaultSize=$(expr ${defaultSize}*1.3 | bc)
	defaultSize=${defaultSize%%.*}
	
	local imgSize="${5:-$defaultSize}"
	
	if [ -z "$imgSize" ] || [ $imgSize -eq 0 ]; then
		imgSize=$defaultSize
	fi

	# If generating an empty image the size of the sparse block should be large
	# enough to allocate an ext4 filesystem using 4096 bytes per inode, this is
	# about 60K, so dd needs a minimum count of 60, with bs=1024 (bytes per IO)
	eval local COUNT="0"
	eval local MIN_COUNT="60"
	if [ $imgSize -lt $MIN_COUNT ]; then
		eval COUNT="$MIN_COUNT"
	fi

	# Create a sparse image block
	log_exec dd if=/dev/zero of=${imagesDir}/${imgName}.$imgType seek=$imgSize count=$COUNT bs=1024
	log_exec mkfs.$imgType -L ${partName} -F -i 4096 ${EXTRA_IMAGECMD} ${imagesDir}/${imgName}.${imgType} -d ${imgRoot}
	# Error codes 0-3 indicate successfull operation of fsck (no errors or errors corrected)
	log_exec "fsck.$imgType -pvfD ${imagesDir}/${imgName}.${imgType} || [ $? -le 3 ]"
}