######################################################################################################################
#                                                                                                                    #
#                                                   SCMS utilities                                                   #
#                                                                                                                    #
######################################################################################################################

# Only use the global variables if there is no per-URI parameter
: ${srcRev:="$SRC_REV"}
: ${srcBranch:="$SRC_BRANCH"}
: ${srcDate:="$SRC_DATE"}

scms_tool=
case $srcUrl in
	# SCMS that have specific URIs that need to be matched first
	git://* | git+ssh://* | ssh://*.git | http://*.git | https://*.git)
		scms_tool="git"
		;;
	svn://* | svn+ssh://*)
		scms_tool="svn"
		;;

	# Generic URLs, managed by the base code
	http://* | https://* | ftp://* | file://*)
		;;
		
	# Generic SCMS URIs
	*://*)
		scms_tool=${srcUrl%%:*}
		;;
esac

# SCMS URLs always use the SCMS ID as URL scheme and may specify a different protocol to use
# In this case we must patch the URL to reference the correct protocol once the SCMS was identified
if [ -n "$srcProtocol" ]; then
	srcUrl=${srcProtocol}://${srcUrl#*://}
fi

#
# Load the SCMS-specific script
#
# This script must define three functions, called with the following parameters
#
#	SCMS_fetch
#		srcUrl			URL of the remote SCMS
#		targetDir		Directory where the code is fetched
#		srcFilename		Filename of the fetched source code
#
#	SCMS_check
#		srcUrl			URL of the remote SCMS
#		targetDir		Directory where the code is fetched
#		srcFilename		Filename of the fetched source code
#
#	SCMS_import
#		srcUrl			URL of the remote SCMS
#		srcFile			Full path to the fetched source code
#		destDir			Directory in which to import the code
#
# These functions may use, but not change, the following variables:
#		srcRev			Exact revision /committo check out
#		srcBranch		Branch or Tag to check out
#		srcDate			Date to be fetched from the branch or tag
#

if [ -n "$scms_tool" ]; then
	# Load the script
	scms_script=$(search_script scms/${scms_tool}_utils.sh)
	if [ -z "$scms_script" ]; then
		fatal 1 "Don't find handler for fetching and importing source code from the $scms_tool Source Code Management System"
	fi
	load_script_once "$scms_script"
fi
